Performs clustering of samples.
clust_samp_func(leaf_node = NULL, dat, clust_vec, clust_samps = TRUE)Dataframe of reordered original dataset when clust_samps == TRUE.
Integer value indicating terminal node id.
Dataframe of the original dataset. Samples may be reordered.
Character vector of variable names to be applied clustering on. Can include class labels.
Logical. If TRUE, hierarchical clustering would be performed among samples within each leaf node.